@@ -7,11 +7,12 @@
 static R_NativePrimitiveArgType dupType[] = {
   INTSXP,  // 1 Ng
   INTSXP,  // 2 SpecsInt
-//  STRSXP,  //  GenoFileFR
-  INTSXP,  // 3 GenoFR
-  INTSXP,  // 4 nDupGenos
-  INTSXP,  // 5 DupGenosFR
-  INTSXP,  // 6 nMisMFR
+  REALSXP, // 3 SpecsDbl
+  INTSXP,  // 4 GenoFR
+  INTSXP,  // 5 nDupGenos
+  INTSXP,  // 6 DupGenosFR
+  INTSXP,  // 7 nMisMFR
+  REALSXP, // 8 DupGenoLR
 };
 
 static R_NativePrimitiveArgType psType[] = {
@@ -39,24 +40,27 @@ static R_NativePrimitiveArgType psType[] = {
   INTSXP,  // 22 DumNoff
   INTSXP,  // 23 DumOff  
   REALSXP, // 24 TotLL
+  INTSXP,  // 25 nTrio
+  INTSXP,  // 26 trioID
+  REALSXP, // 27 trioLR
 };
 
-extern void F77_NAME(duplicates)(int *Ng, int *SpecsInt, int *GenoFR, 
-  int *nDupGenos, int *DupGenosFR, int *nMisMFR);
+extern void F77_NAME(duplicates)(int *Ng, int *SpecsInt, float *SpecsDbl,
+  int *GenoFR, int *nDupGenos, int *DupGenosFR, int *nMisMFR, float *DupGenoLR);
 
 extern void F77_NAME(makeped)(int *Ng, int *SpecsInt, float *SpecsDbl,
   int *GenoFR, int *SexRF, int *BYRF, int *APRF, int *parentsRF, 
   float *LrRF, int *OhRF, int *nAmb, int *AmbigID, int *AmbigSex, 
   int *AmbigAgeDif, int *AmbigRel, float *AmbigLR, int *AmbigOH,
-  int *Nd, int *DumParRF, float *DumLrRF, int *DumBYRF, 
-  int *DumNoff, int *DumOff,  float *TotLL);  
+  int *Nd, int *DumParRF, float *DumLrRF, int *DumBYRF, int *DumNoff, 
+  int *DumOff,  float *TotLL, int *nTrio, int *trioID, float *trioLR);  
 
 extern void F77_NAME(deallocall)();
 
 
 static const R_FortranMethodDef FortranEntries[] = {
-  {"duplicates", (DL_FUNC) &F77_NAME(duplicates), 6, dupType},
-  {"makeped", (DL_FUNC) &F77_NAME(makeped), 24, psType},
+  {"duplicates", (DL_FUNC) &F77_NAME(duplicates), 8, dupType},
+  {"makeped", (DL_FUNC) &F77_NAME(makeped), 27, psType},
   {"deallocall", (DL_FUNC) &F77_NAME(deallocall), 0},
   {NULL, NULL, 0}
 };
